===================
Welcome to torauth
===================

.. image:: https://badge.fury.io/py/torauth.svg
    :target: http://badge.fury.io/py/torauth

.. image:: https://travis-ci.org/longniao/torauth.svg
    :target: https://travis-ci.org/longniao/torauth

.. image:: https://img.shields.io/pypi/v/torauth.svg
    :target: https://pypi.python.org/pypi/torauth/

.. image:: https://img.shields.io/pypi/wheel/torauth.svg
    :target: https://pypi.python.org/pypi/torauth/

.. image:: https://img.shields.io/pypi/pyversions/torauth.svg
    :target: https://pypi.python.org/pypi/torauth/

.. image:: https://img.shields.io/pypi/l/torauth.svg
    :target: https://pypi.python.org/pypi/torauth/


An authentication, registration, account management for `TorStack`_ of `Tornado`_.


Installing
----------

Install and update using `pip`_:

.. code-block:: text

    pip install -U torauth


.. _TorStack: https://github.com/longniao/torstack
.. _Tornado: http://www.tornadoweb.org
.. _pip: https://pip.pypa.io/en/stable/quickstart/